%define name fftw
%define version 2.1.3
%define release 3mdk

Name: %{name}
Summary: fast fourier transform library
Version: %{version}
Release: %{release}
Copyright: GPL
Icon: fftw-logo-thumb.gif
Group: Development/C
Prefix: /usr
BuildRoot: /var/tmp/%{name}-buildroot
Source: fftw-2.1.3.tar.bz2
URL: http://www.fftw.org
Packager : Dara Hazeghi <dara@pacbell.net>

%description
FFTW is a collection of fast C routines for computing the Discrete Fourier
Transform in one or more dimensions.  It includes complex, real, and
parallel transforms, and can handle arbitrary array sizes efficiently.
This RPM package includes both the double- and single-precision FFTW
uniprocessor and threads libraries.  (The single-precision files have
an "s" prefix.)

%package devel
Summary: headers, libraries, & docs for FFTW fast fourier transform library
Group: Development/C
Prefix: %{prefix}
Requires: fftw = %{version}-%{release}

%description devel
This package contains the additional header files, documentation, and
libraries you need to develop programs using the FFTW fast fourier
transform library.

%prep

# We will be compiling two copies of FFTW, one for double precision and
# one for single precision.  During the build process, these copies
# will be stored in fftw-%{version}/double and fftw-%{version}/single

# Unpack the tar archive, first (-c) creating a fftw-%{version}
# directory and then unpacking in there.

%setup -c
# Now, rename the unpacked FFTW directory to "double":
mv ${RPM_PACKAGE_NAME}-${RPM_PACKAGE_VERSION} double
# Second, make a copy of this directory in "single":
cp -r double single

%build

# Configure and build the double and single precision versions.
# Notes:
#  (1) We install into ${RPM_BUILD_ROOT}, which is set either
#      by the BuildRoot option above or by --buildroot at build-time.
#      This allows you to build the RPM without blowing away your existing
#      FFTW installation, and even without being root.
#  (2) The double-precision version is installed with the normal library
#      names, while the single-precision version is installed with an "s"
#      prefix.

cd double

%ifarch i386
./configure --prefix="${RPM_BUILD_ROOT}%{prefix}" --enable-shared --enable-i386-hacks --enable-threads

%else
./configure --prefix="${RPM_BUILD_ROOT}%{prefix}" --enable-shared --enable-threads

%endif
make
cd ../single
./configure --prefix="${RPM_BUILD_ROOT}%{prefix}" --enable-shared --enable-type-prefix --enable-threads --enable-float
make -j 2

%install
cd double
make install
cd ../single
make install

%clean

rm -rf ${RPM_BUILD_ROOT}

%post
# Force ${RPM_INSTALL_PREFIX}/lib to be in /etc/ld.so.conf?
# No...that would make it impossible to completely uninstall reliably.
# Instead, warn the user fix a broken /etc/ld.so.conf manually:
if test -z `grep ${RPM_INSTALL_PREFIX}/lib /etc/ld.so.conf`; then
     echo "warning: ${RPM_INSTALL_PREFIX}/lib is not in /etc/ld.so.conf" 1>&2
     echo "         You should add it and then run ldconfig." 1>&2
fi

# run ldconfig to update the runtime linker database with the new libraries
# (make sure /sbin is in the $PATH)
PATH="/sbin:$PATH" ldconfig

%postun
# after uninstall, run ldconfig to remove the libs from the linker database
PATH="/sbin:$PATH" ldconfig

%files
%defattr (-,root,root)
/usr/lib/libfftw.so.2.0.5
/usr/lib/libfftw_threads.so.2.0.5
/usr/lib/librfftw.so.2.0.5
/usr/lib/librfftw_threads.so.2.0.5
/usr/lib/libsfftw.so.2.0.5
/usr/lib/libsfftw_threads.so.2.0.5
/usr/lib/libsrfftw.so.2.0.5
/usr/lib/libsrfftw_threads.so.2.0.5
/usr/lib/libfftw.so.2
/usr/lib/libfftw_threads.so.2
/usr/lib/librfftw.so.2
/usr/lib/librfftw_threads.so.2
/usr/lib/libsfftw.so.2
/usr/lib/libsfftw_threads.so.2
/usr/lib/libsrfftw.so.2
/usr/lib/libsrfftw_threads.so.2

%files devel
%defattr (-,root,root)
/usr/include/fftw.h
/usr/include/fftw_threads.h
/usr/include/rfftw.h
/usr/include/rfftw_threads.h
/usr/include/sfftw.h
/usr/include/sfftw_threads.h
/usr/include/srfftw.h
/usr/include/srfftw_threads.h
/usr/info/*
/usr/lib/libfftw.a
/usr/lib/libfftw.la
/usr/lib/libfftw.so
/usr/lib/libfftw_threads.a
/usr/lib/libfftw_threads.la
/usr/lib/libfftw_threads.so
/usr/lib/librfftw.a
/usr/lib/librfftw.la
/usr/lib/librfftw.so
/usr/lib/librfftw_threads.a
/usr/lib/librfftw_threads.la
/usr/lib/librfftw_threads.so
/usr/lib/libsfftw.a
/usr/lib/libsfftw.la
/usr/lib/libsfftw.so
/usr/lib/libsfftw_threads.a
/usr/lib/libsfftw_threads.la
/usr/lib/libsfftw_threads.so
/usr/lib/libsrfftw.a
/usr/lib/libsrfftw.la
/usr/lib/libsrfftw.so
/usr/lib/libsrfftw_threads.a
/usr/lib/libsrfftw_threads.la
/usr/lib/libsrfftw_threads.so

%changelog
* Wed Apr 26 2000 Lenny Cartier <lenny@mandrakesoft.com> 2.1.3-3mdk
- fix group
- spec helper fixes

* Tue Jan 25 2000 Lenny Cartier <lenny@mandrakesoft.com>
- updated, installs in /usr instead of /usr/local by Dara Hazeghi
  <dara@pacbell.net>

* Thu Dec 16 1999 Lenny Cartier <lenny@mandrakesoft.com>
- new in contribs
- bz2 archive 
- add defattr
